 This file is created the GLADE version [here](http://elysium.elte.hu/~dalyag/GLADE+.txt), columns are [here](http://elysium.elte.hu/~dalyag/GLADE+_columns.txt) **Version May 28th**. We first select the columns of interest with [this script](https://git.ligo.org/cbc-cosmo/gwcosmo/-/blob/pending_review/scripts_galaxy_catalogs/GLADE+/select_columnts.sh) and then create the catalog with this [script](https://git.ligo.org/cbc-cosmo/gwcosmo/-/blob/pending_review/scripts_galaxy_catalogs/GLADE+/create_glade+.py)
